@@ -5,14 +5,14 @@ import geospacelab.express.eiscat_dashboard as eiscat
 
 
 def test_UHF_CP2():
-    dt_fr = datetime.datetime.strptime('20211010' + '1700', '%Y%m%d%H%M')
-    dt_to = datetime.datetime.strptime('20211010' + '2100', '%Y%m%d%H%M')
+    dt_fr = datetime.datetime.strptime('20161023' + '1600', '%Y%m%d%H%M')
+    dt_to = datetime.datetime.strptime('20161023' + '2100', '%Y%m%d%H%M')
 
     site = 'UHF'
     antenna = 'UHF'
-    modulation = 'ant'
+    modulation = '44.4'
     load_mode = 'AUTO'
-    data_file_type = 'madrigal-hdf5'
+    data_file_type = 'eiscat-hdf5'
 
     dashboard = eiscat.EISCATDashboard(dt_fr, dt_to, site=site, antenna=antenna, modulation=modulation,
                                  data_file_type=data_file_type, load_mode=load_mode, status_control=True,
@@ -20,7 +20,7 @@ def test_UHF_CP2():
 
     # select beams before assign the variables
     # dashboard.dataset.select_beams(field_aligned=True)
-    # dashboard.dataset.select_beams(az_el_pairs=[(188.6, 77.7)])
+    dashboard.dataset.select_beams(az_el_pairs=[(187.0, 77.7)])
     dashboard.check_beams()
 
     dashboard.status_mask()
@@ -29,6 +29,9 @@ def test_UHF_CP2():
     T_i = dashboard.assign_variable('T_i')
     T_e = dashboard.assign_variable('T_e')
     v_i = dashboard.assign_variable('v_i_los')
+    v_i_2 = v_i.clone()
+    v_i_2.value = v_i_2.value
+    v_i.visual.axis[2].lim=[-100, 100]
     az = dashboard.assign_variable('AZ')
     el = dashboard.assign_variable('EL')
     ptx = dashboard.assign_variable('P_Tx')
@@ -208,12 +211,11 @@ def test_vhf_lowel():
 
 
 if __name__ == "__main__":
-    db = test_vhf_lowel()
+    # db = test_vhf_lowel()
 
-    test_uhf_cp3()
+    # test_uhf_cp3()
     test_UHF_CP2()
-    test_esr_32m()
+    # test_esr_32m()
 
     plt.savefig('eiscat_example.png')
-    plt.show()
-    db.list_sourced_datasets()
\ No newline at end of file
+    plt.show()
\ No newline at end of file
